How to manage Linux server with GUI
================================================================================
A typical Linux server runs in a command line interface (CLI) environment, preloaded with bare essential tools needed to install and configure various headless services. Compared to a full-blown GUI desktop image, such a minimal setup is advantageous in terms of security, resource consumption and speed.

If you are used to GUI-based environment, however, you may wonder whether there is a GUI for Linux server. A typical Linux desktop environment like GNOME, KDE, etc. will probably be too resource-heavy for what it's worth, and not as secure simply because there will be more code subject to potential security vulnerabilities.

An alternative to a full-blown desktop GUI is to use a **web-based server administration tool**. There are several web-based system configuration tools, such as [Webmin][1], [ISPconfig][2], [Zentyal][3], etc.

In this tutorial, I will describe **how to manage and configure a Linux server with Webmin's web-based GUI**.

Webmin is a lightweight (~20 MB) system configuration tool written in Perl. Webmin has a built-in web server, allowing users to configure a Linux server via web interface. One of its strength is its modular architecture where you can load modules to Webmin to extend its functionality.

### Install Webmin on Linux Server ###

To install Webmin on Ubuntu or Debian server, you can use the following commands.

    $ sudo apt-get install perl libnet-ssleay-perl openssl libauthen-pam-perl libpam-runtime libio-pty-perl apt-show-versions python
    $ wget http://prdownloads.sourceforge.net/webadmin/webmin_1.660_all.deb
    $ sudo dpkg -i webmin_1.660_all.deb 

To install Webmin on CentOS or RHEL server, use these commands.

    $ wget http://prdownloads.sourceforge.net/webadmin/webmin_1.660_all.deb
    $ sudo rpm -U webmin-1.660-1.noarch.rpm 

### Access Webmin Interface ###

Once you installed Webmin, you can access Webmin by going to https://<HOST_IP>:10000 on a web browser. If you have a firewall enabled, make sure that TCP 10000 port is not blocked.

Also, note that you should use HTTPS, not HTTP. Otherwise, you will get a redirection error. By default, Webmin runs in SSL mode with a default SSL certificate generated by Webmin.

Once you see Webmin's login page, you can log in as root (with the root password) or as any user who can use sudo on the Linux server. After logging in, you will see the status summary of your Linux server as follows.

[![](http://farm4.staticflickr.com/3803/10937800943_e1ac465c3f_z.jpg)][4]

### Webmin Features ###

Webmin boasts of an extremely rich set of features that allow you to configure almost every aspect of a given Linux server. In the following, let me give you a glimpse of some of its powerful features.

Enable or disable boot-time services, and show their configuration status.

[![](http://farm8.staticflickr.com/7437/10937589506_7abcaac10e_z.jpg)][5]

Monitor the status of server and services in real time, and configure scheduled monitoring and notification emails. Here you can monitor various server daemons such as NFS, MySQL, BIND DNS, Squid proxy, Apache Web server, etc., as well as system resources such as disk storage, memory or network traffic.

Configure iptables-based firewall rules.

[![](http://farm4.staticflickr.com/3679/10937801173_61cd4b11a3_z.jpg)][6]

Configure local routing table and gateways.

Mount and configure a filesystem.

[![](http://farm4.staticflickr.com/3710/10937589556_9fd192cdb9_z.jpg)][7]

Access and modify local file system via web-based file manager interface. This requires Java plugin for web browser.

Change Webmin configurations, where you can access-control IP addresses, add/remove Webmin modules, enable two-factor authentication for secure login, set up certificate authority, etc.

[![](http://farm8.staticflickr.com/7317/10937532015_b5e1263496_z.jpg)][8]

--------------------------------------------------------------------------------

via: http://xmodulo.com/2013/11/manage-linux-server-gui.html

译者：[译者ID](https://github.com/译者ID) 校对：[校对者ID](https://github.com/校对者ID)

本文由 [LCTT](https://github.com/LCTT/TranslateProject) 原创翻译，[Linux中国](http://linux.cn/) 荣誉推出

[1]:http://www.webmin.com/
[2]:http://www.ispconfig.org/
[3]:http://www.zentyal.org/
[4]:http://www.flickr.com/photos/xmodulo/10937800943/
[5]:http://www.flickr.com/photos/xmodulo/10937589506/
[6]:http://www.flickr.com/photos/xmodulo/10937801173/
[7]:http://www.flickr.com/photos/xmodulo/10937589556/
[8]:http://www.flickr.com/photos/xmodulo/10937532015/